Struct MissileFlags
pub struct MissileFlags(/* private fields */);Expand description
Missile flags on launch.
Implementations
impl MissileFlags
impl MissileFlags
pub const fn empty() -> MissileFlags
pub const fn empty() -> MissileFlags
Get a flags value with all bits unset.
pub const fn all() -> MissileFlags
pub const fn all() -> MissileFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<MissileFlags>
pub const fn from_bits(bits: u32) -> Option<MissileFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> MissileFlags
pub const fn from_bits_truncate(bits: u32) -> MissileFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> MissileFlags
pub const fn from_bits_retain(bits: u32) -> MissileFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<MissileFlags>
pub fn from_name(name: &str) -> Option<MissileFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: MissileFlags) -> bool
pub const fn intersects(&self, other: MissileFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: MissileFlags) -> bool
pub const fn contains(&self, other: MissileFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: MissileFlags)
pub fn insert(&mut self, other: MissileFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: MissileFlags)
pub fn remove(&mut self, other: MissileFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: MissileFlags)
pub fn toggle(&mut self, other: MissileFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: MissileFlags, value: bool)
pub fn set(&mut self, other: MissileFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: MissileFlags) -> MissileFlags
pub const fn intersection(self, other: MissileFlags) -> MissileFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: MissileFlags) -> MissileFlags
pub const fn union(self, other: MissileFlags) -> MissileFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: MissileFlags) -> MissileFlags
pub const fn difference(self, other: MissileFlags) -> MissileFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: MissileFlags) -> MissileFlags
pub const fn symmetric_difference(self, other: MissileFlags) -> MissileFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> MissileFlags
pub const fn complement(self) -> MissileFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl MissileFlags
impl MissileFlags
pub const fn iter(&self) -> Iter<MissileFlags>
pub const fn iter(&self) -> Iter<MissileFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<MissileFlags>
pub const fn iter_names(&self) -> IterNames<MissileFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.